@@ -739,9 +739,9 @@ setMethod("intersect.idx",
 
 
 ##' @rdname set_operations
-##' @aliases %in%.nanotime
+##' @method %in% nanotime
 `%in%.nanotime` <- function(x, table) {
-    if (class(table) == "nanoival") {
+    if (inherits(table, "nanoival")) {
         if (is.unsorted(x)) stop("x must be sorted")
         table <- sort(table)
         nanoival_intersect_idx_time_interval_logical_impl(x, table)
@@ -750,15 +750,14 @@ setMethod("intersect.idx",
     }
 }
 
-## ##' @rdname set_operations
-## ##' @aliases %in%,nanotime,nanoival-method
-## setMethod("%in%",
-##           c("nanotime", "nanoival"),
-##           function(x, table) {
-##               if (is.unsorted(x)) stop("x must be sorted")
-##               table <- sort(table)
-##               nanoival_intersect_idx_time_interval_logical_impl(x, table)
-##           })
+##' @rdname set_operations
+setMethod("%in%",
+          c("nanotime", "nanoival"),
+          function(x, table) {
+              if (is.unsorted(x)) stop("x must be sorted")   ## #nocov
+              table <- sort(table)                           ## #nocov
+              nanoival_intersect_idx_time_interval_logical_impl(x, table)  ## #nocov
+          })
 
 ##' @rdname set_operations
 setMethod("intersect",
@@ -974,3 +973,7 @@ setMethod("rep", c(x = "nanoival"), function(x, ...) {
     new("nanoival", callNextMethod())
 })
 
+##' @rdname nanoival
+as.character.nanoival <- function(x, ...) {
+    format(x, ...)
+}
